@@ -68,6 +68,8 @@ COMMANDS = {
     # path, scene, time
     "LOAD_VOLUME_FROM_FILE": [39, "S", "I32", "I32"],
     "SET_TIME": [40, "I32"],
+    "SET_BOUNDING_BOX_COLOR": [41, "F32", "F32", "F32"],
+    "SHOW_BOUNDING_BOX": [42, "I32"],
 }
 
 
